==> haskell-network-3.1.2.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network
version:              3.1.2.1
visibility:           public
id:                   network-3.1.2.1-ESgFvcx6XpxGXZaMhj9jv9
key:                  network-3.1.2.1-ESgFvcx6XpxGXZaMhj9jv9
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto, Evan Borden
homepage:             https://github.com/haskell/network
synopsis:             Low-level networking interface
description:
    This package provides a low-level networking interface.

    === High-Level Packages
    Other packages provide higher level interfaces:

    * connection
    * hookup
    * network-simple

    === Extended Packages
    @network@ seeks to provide a cross-platform core for networking. As such some
    APIs live in extended libraries. Packages in the @network@ ecosystem are
    often prefixed with @network-@.

    ==== @network-bsd@
    In @network-3.0.0.0@ the @Network.BSD@ module was split off into its own
    package, @network-bsd-3.0.0.0@.

    ==== @network-uri@
    In @network-2.6@ the @Network.URI@ module was split off into its own package,
    @network-uri-2.6@. If you'\''re using the @Network.URI@ module you can
    automatically get it from the right package by adding this to your @.cabal@
    file:

    > library
    >   build-depends: network-uri-flag

category:             Network
abi:                  9d310702d7255b2b1e54de3ccd8a1d69
exposed:              True
exposed-modules:
    Network.Socket Network.Socket.Address Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal

hidden-modules:
    Network.Socket.Buffer Network.Socket.ByteString.IO
    Network.Socket.ByteString.Internal Network.Socket.Cbits
    Network.Socket.Fcntl Network.Socket.Flag Network.Socket.Handle
    Network.Socket.If Network.Socket.Imports Network.Socket.Info
    Network.Socket.Name Network.Socket.Options Network.Socket.ReadShow
    Network.Socket.Shutdown Network.Socket.SockAddr
    Network.Socket.Syscall Network.Socket.Types Network.Socket.Unix
    Network.Socket.ByteString.Lazy.Posix Network.Socket.Posix.Cmsg
    Network.Socket.Posix.CmsgHdr Network.Socket.Posix.IOVec
    Network.Socket.Posix.MsgHdr

import-dirs:          /usr/lib/ghc-8.10.3/site-local/network-3.1.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/network-3.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/network-3.1.2.1
hs-libraries:         HSnetwork-3.1.2.1-ESgFvcx6XpxGXZaMhj9jv9
include-dirs:         /usr/lib/ghc-8.10.3/site-local/network-3.1.2.1/include
includes:             HsNet.h HsNetDef.h alignment.h win32defs.h
depends:
    base-4.14.1.0 bytestring-0.10.12.0 deepseq-1.4.4.0
    directory-1.3.6.0

haddock-interfaces:   /usr/share/doc/haskell-network/html/network.haddock
haddock-html:         /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-3.1.2.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network
version:              3.1.2.1
visibility:           public
id:                   network-3.1.2.1-9WverI7TsZxF8B2t7LMF4x
key:                  network-3.1.2.1-9WverI7TsZxF8B2t7LMF4x
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto, Evan Borden
homepage:             https://github.com/haskell/network
synopsis:             Low-level networking interface
description:
    This package provides a low-level networking interface.

    === High-Level Packages
    Other packages provide higher level interfaces:

    * connection
    * hookup
    * network-simple

    === Extended Packages
    @network@ seeks to provide a cross-platform core for networking. As such some
    APIs live in extended libraries. Packages in the @network@ ecosystem are
    often prefixed with @network-@.

    ==== @network-bsd@
    In @network-3.0.0.0@ the @Network.BSD@ module was split off into its own
    package, @network-bsd-3.0.0.0@.

    ==== @network-uri@
    In @network-2.6@ the @Network.URI@ module was split off into its own package,
    @network-uri-2.6@. If you'\''re using the @Network.URI@ module you can
    automatically get it from the right package by adding this to your @.cabal@
    file:

    > library
    >   build-depends: network-uri-flag

category:             Network
abi:                  d95326e3022a3fec371ab12e6142bbed
exposed:              True
exposed-modules:
    Network.Socket Network.Socket.Address Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal

hidden-modules:
    Network.Socket.Buffer Network.Socket.ByteString.IO
    Network.Socket.ByteString.Internal Network.Socket.Cbits
    Network.Socket.Fcntl Network.Socket.Flag Network.Socket.Handle
    Network.Socket.If Network.Socket.Imports Network.Socket.Info
    Network.Socket.Name Network.Socket.Options Network.Socket.ReadShow
    Network.Socket.Shutdown Network.Socket.SockAddr
    Network.Socket.Syscall Network.Socket.Types Network.Socket.Unix
    Network.Socket.ByteString.Lazy.Posix Network.Socket.Posix.Cmsg
    Network.Socket.Posix.CmsgHdr Network.Socket.Posix.IOVec
    Network.Socket.Posix.MsgHdr

import-dirs:          /usr/lib/ghc-8.10.3/site-local/network-3.1.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/network-3.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/network-3.1.2.1
hs-libraries:         HSnetwork-3.1.2.1-9WverI7TsZxF8B2t7LMF4x
include-dirs:         /usr/lib/ghc-8.10.3/site-local/network-3.1.2.1/include
includes:             HsNet.h HsNetDef.h alignment.h win32defs.h
depends:
    base-4.14.1.0 bytestring-0.10.12.0 deepseq-1.4.4.0
    directory-1.3.6.0

haddock-interfaces:   /usr/share/doc/haskell-network/html/network.haddock
haddock-html:         /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
